pub enum FilterOutput<T> {
WarmingUp {
samples: usize,
required: usize,
},
Ready(T),
}Expand description
Output from a temporal filter.
Variants
WarmingUp
The fixed window has not yet received enough samples.
Fields
Ready(T)
The filter has enough state to produce a value.
Implementations