Stability

Enum Stability 

pub enum Stability<T> {
    WarmingUp {
        samples: usize,
        required: usize,
    },
    Unstable {
        minimum: T,
        maximum: T,
        span: u64,
    },
    Stable {
        minimum: T,
        maximum: T,
        span: u64,
    },
}
Classification returned by a StabilityDetector.

Variants



WarmingUp

The detector has not yet received a full window.

Fields

samples: usize

Number of samples currently retained.

required: usize

Number of samples required for classification.



Unstable

The full window exceeds the configured range threshold.

Fields

minimum: T

Minimum retained sample.

maximum: T

Maximum retained sample.

span: u64

Difference between maximum and minimum in sample quanta.



Stable

The full window is within the configured range threshold.

Fields

minimum: T

Minimum retained sample.

maximum: T

Maximum retained sample.

span: u64

Difference between maximum and minimum in sample quanta.